pub struct L2Message {
pub dest_chain_id: U256,
pub source_chain_id: u64,
pub from: Address,
pub to: Address,
pub value: U256,
pub gas_limit: U256,
pub tx_id: U256,
pub data: Bytes,
}Expand description
Represents a message from the L2 to another L2
Fields
dest_chain_id: U256Chain id of the destination chain
source_chain_id: u64Chain id of the source chain
from: AddressAddress that originated the transaction
to: AddressAddress of the recipient in the destination chain
value: U256Amount of ETH to send to the recipient
gas_limit: U256Gas limit for the transaction execution in the destination chain
tx_id: U256Unique transaction id for the message in the destination chain
data: BytesCalldata for the transaction in the destination chain
Implementations